aboutsummaryrefslogtreecommitdiff
path: root/debian/patches/spelling.patch
blob: 343cba336e407bf81dc496c9872e56d697885d8b (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
Description: Correct spelling
Author: Dmitry Borisyuk <q1werty@i.com.ua>
--- a/fbxkb.c
+++ b/fbxkb.c
@@ -40,7 +40,7 @@
 
 #define IMGPREFIX PREFIX "/share/fbxkb/images/"
 /******************************************************************
- * GLOBAL VARSIABLES                                              *
+ * GLOBAL VARIABLES                                               *
  ******************************************************************/
 
 /* X11 common stuff */
@@ -48,7 +48,7 @@
 static Display *dpy;
 static int xkb_event_type;
 
-/* internal state mashine */
+/* internal state machine */
 static int cur_group;
 static int ngroups;
 static GHashTable *sym2pix;
@@ -383,11 +383,11 @@
     }
  out:
     XkbFreeKeyboard(kbd_desc_ptr, 0, True);
     // sanity check: group numbering must be continous
     for (i = 0; (i < XkbNumKbdGroups) && (group2info[i].sym != NULL); i++);
     if (i != ngroups) {
-        ERR("kbd group numbering is not continous\n");
-        ERR("run 'xlsatoms | grep pc' to know what hapends\n");
+        ERR("kbd group numbering is not continuous\n");
+        ERR("run 'xlsatoms | grep pc' to know what happens\n");
         exit(1);
     }
  out_us:
@@ -383,11 +383,11 @@
  out:
     XkbFreeKeyboard(kbd_desc_ptr, 0, True);
-    // sanity check: group numbering must be continous
+    // sanity check: group numbering must be continuous
     for (i = 0; (i < XkbNumKbdGroups) && (group2info[i].sym != NULL); i++);
     if (i != ngroups) {
bgstack15